pref("browser.newtab.preload", false);
pref("services.sync.engine.mozcn.ntab", false);

// keep these defaults until we don't need to migrate pref to localStorage
pref("moa.ntab.view", "quickdial");
pref("moa.ntab.qdtab", "grid");
pref("moa.ntab.qdtab.used", false);
pref("moa.ntab.openInNewTab", true);
pref("moa.ntab.dial.column", 4);
pref("moa.ntab.dial.row", 2);

pref("moa.ntab.displayfooter", true);

pref("moa.ntab.view.firefoxchina.url", "http://n.firefoxchina.cn/?from=ntab_bottom");

pref("moa.ntab.openLinkInNewTab", false);
pref("moa.ntab.loadInExistingTabs", false);

pref("moa.ntab.backgroundcolor", "transparent");
pref("moa.ntab.backgroundimage", "");
pref("moa.ntab.backgroundimagestyle", "fill");
pref("moa.ntab.backgroundnoise", true);

pref("moa.ntab.dial.showSearch", true);
pref("moa.ntab.dial.hideSearch", false);

pref("moa.ntab.dial.extrawidth", 0);
pref("moa.ntab.dial.useopacity", false);
pref("moa.ntab.dial.refreshhack", false);

pref("moa.ntab.contextMenuItem.show", true);

pref("moa.ntab.display.usehotkey", false);

pref("moa.signatureverifier.key", "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDbjn89QtfQeDfU1KDdHsy7dWEZxixJSvaAOGX05NOvLbh7Uo6tlMKFJyYZ7unxlfMAsewZBOCaMxEYgU4h5J0PAgUs+zTg3MzCnDA0Ku1zQrvoa1iaTsVxzpHTFeOK29HSGX2qC4sVUP+ZRqa11oaBaIjpuJ3szo9nGy4CWvHMLQIDAQAB");
